@@ -52,7 +52,9 @@ class EnglishUtils:
     def _adjust_ending(cls, word, strip_chars, add_suffix):
         return (word[:-strip_chars] if strip_chars else word) + add_suffix
 
-    _COMPOUND_PLURAL_SIMPLE_PREPOSITIONS = ['about', 'at', 'by', 'for', 'in', 'of', 'on', 'to', 'with']
+    _COMPOUND_PLURAL_SIMPLE_PREPOSITIONS = [
+        'about', 'at', 'between', 'by', 'for', 'from', 'in', 'of', 'on', 'to', 'with'
+    ]
 
     # Phrases like 'using', 'used by', 'used in', etc. function similarly to prepositions when doing pluralization
     # in that the plural of 'a variant referencing a gene' would be 'variants referencing genes', just as
@@ -478,7 +480,9 @@ class EnglishUtils:
         >>> conjoined_list(['up', 'down', 'all around'], comma=False)
         'up and down and all around'
 
-        :param items: a list of items
+        :param items: a list of items.
+            If a dictionary is given, a list of its keys will be used.
+            If a set is used, it will be converted to a sorted list.
         :param conjunction: a string (default 'and') to be used before the last item if there's more than one
         :param comma: a string (default ',') to use as a comma. Semicolon (';') is the most obvious other choice,
                       or False to indicate that the conjunction should be used between all elements.
@@ -508,6 +512,11 @@ class EnglishUtils:
             assert isinstance(oxford_comma, str), "The 'oxford_comma' argument must a string or boolean."
             final_sep = oxford_comma + whitespace
 
+        if isinstance(items, dict):
+            items = list(items.keys())
+        elif isinstance(items, set):
+            items = sorted(items)
+
         n = len(items)
 
         if n == 0:
